@@ -421,6 +421,9 @@ static PyTypeObject __pyx_AsyncGenType_type = {
 #elif PY_VERSION_HEX >= 0x030400a1
     0,                                          /* tp_finalize */
 #endif
+#if PY_VERSION_HEX >= 0x030800b1
+    0,                                          /*tp_vectorcall*/
+#endif
 };
 
 
@@ -650,6 +653,9 @@ static PyTypeObject __pyx__PyAsyncGenASendType_type = {
 #if PY_VERSION_HEX >= 0x030400a1
     0,                                          /* tp_finalize */
 #endif
+#if PY_VERSION_HEX >= 0x030800b1
+    0,                                          /*tp_vectorcall*/
+#endif
 };
 
 
@@ -759,6 +765,9 @@ static PyTypeObject __pyx__PyAsyncGenWrappedValueType_type = {
 #if PY_VERSION_HEX >= 0x030400a1
     0,                                          /* tp_finalize */
 #endif
+#if PY_VERSION_HEX >= 0x030800b1
+    0,                                          /*tp_vectorcall*/
+#endif
 };
 
 
@@ -1038,6 +1047,9 @@ static PyTypeObject __pyx__PyAsyncGenAThrowType_type = {
 #if PY_VERSION_HEX >= 0x030400a1
     0,                                          /* tp_finalize */
 #endif
+#if PY_VERSION_HEX >= 0x030800b1
+    0,                                          /*tp_vectorcall*/
+#endif
 };
 
 
